Enum sdl2::pixels::Color
[−]
[src]
pub enum Color {
RGB(u8, u8, u8),
RGBA(u8, u8, u8, u8),
}Variants
RGB | |
RGBA |
pub enum Color {
RGB(u8, u8, u8),
RGBA(u8, u8, u8, u8),
}RGB | |
RGBA |
impl Colorfn to_u32(&self, format: &PixelFormat) -> u32fn from_u32(format: &PixelFormat, pixel: u32) -> Colorfn get_rgb(&self) -> (u8, u8, u8)impl Rand for Colorimpl Debug for Colorimpl Hash for Colorfn hash<__H: Hasher>(&self, __arg_0: &mut __H)fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasherimpl PartialEq for Colorimpl Eq for Colorimpl Clone for Colorfn clone(&self) -> Colorfn clone_from(&mut self, source: &Self)impl Copy for Color
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).
Search functions by type signature (e.g.
vec -> usize)